plan_drop_item_name

Function plan_drop_item_name 

fn plan_drop_item_name(
    scx: &StatementContext<'_>,
    object_type: ObjectType,
    if_exists: bool,
    name: UnresolvedItemName,
) -> Result<Option<CatalogItemId>, PlanError>
Resolves name to the CatalogItemId of the item to drop, performing the system-object check but not the dependency check. Returns None if the item does not exist and if_exists is set.