fn ensure_no_blocking_dependents(
scx: &StatementContext<'_>,
object_type: ObjectType,
catalog_item: &dyn CatalogItem,
also_dropped: &BTreeSet<CatalogItemId>,
) -> Result<(), PlanError>Expand description
Errors if dropping catalog_item would leave a dangling dependent, i.e. an
object that depends on it and is not itself being dropped. Dependents whose
ids are in also_dropped are ignored, since they are being dropped as part
of the same statement.